# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# With UsrMove (F-17, RHEL-7 onwards), we want the library installed to %%{_libdir} rather than /%%{_lib}
%global UsrMove %([ 0%{?fedora} -gt 16 -o 0%{?rhel} -gt 6 ] && echo 1 || echo 0)

# Determine location of fipshmac binary
%global __fipshmac %([ -x /usr/bin/fipshmac ] && echo /usr/bin/fipshmac || echo /bin/fipshmac)

Name:		libgcrypt
Version:	1.7.9
Release:	1.0.cf.%{__distinit}%{__distvers}
# Technically LGPLv2.1+, but Fedora's table doesn't draw a distinction.
# Documentation and some utilities are GPLv2+ licensed.
# These files are in the devel subpackage.
License:	LGPLv2+
Summary:	A general-purpose cryptography library
URL:		http://www.gnupg.org/
Source0:	ftp://ftp.gnupg.org/gcrypt/libgcrypt/libgcrypt-%{version}.tar.bz2
Source1:	ftp://ftp.gnupg.org/gcrypt/libgcrypt/libgcrypt-%{version}.tar.bz2.sig
Source2:	wk@g10code.com
Source6:	t-mpi-point.c
# make FIPS hmac compatible with fipscheck - non upstreamable
# update on soname bump
Patch2:		libgcrypt-1.6.2-use-fipscheck.patch
# fix tests in the FIPS mode, fix the FIPS-186-3 DSA keygen
Patch5:		libgcrypt-1.7.3-tests.patch
# add configurable source of RNG seed and seed by default
# from /dev/urandom in the FIPS mode
Patch6:		libgcrypt-1.7.3-fips-cfgrandom.patch
# update the CAVS tests
Patch7:		libgcrypt-1.7.3-fips-cavs.patch
# use poll instead of select when gathering randomness
Patch11:	libgcrypt-1.7.6-use-poll.patch
# slight optimalization of mpicoder.c to silence Valgrind (#968288)
Patch13:	libgcrypt-1.6.1-mpicoder-gccopt.patch
# Run the FIPS mode initialization in the shared library constructor
Patch18:	libgcrypt-1.6.2-fips-ctor.patch
# update the selftests for new FIPS requirements
Patch22:	libgcrypt-1.7.3-fips-reqs.patch
# do not use strict aliasing for bufhelp functions
Patch23:	libgcrypt-1.7.3-aliasing.patch
# use only urandom if /dev/random cannot be opened
Patch24:	libgcrypt-1.6.3-urandom-only.patch

BuildRequires:	gawk, gcc, libgpg-error-devel >= 1.11, make, pkgconfig
BuildRequires:	openssl
BuildRequires:	fipscheck
%if %{UsrMove}
%global library_dir %{_libdir}
Conflicts:	filesystem < 3
%else
%global library_dir /%{_lib}
BuildRequires:	symlinks
%endif
# this is needed only when patching the .texi doc
BuildRequires:	texinfo

%description
Libgcrypt is a general purpose crypto library based on the code used
in GNU Privacy Guard.

%package devel
Summary:	Development files for the libgcrypt package
License:	LGPLv2+ and GPLv2+
Requires:	%{name}%{?_isa} = %{version}-%{release}
Requires:	libgpg-error-devel
Requires(post):	/sbin/install-info
Requires(preun): /sbin/install-info

%description devel
Libgcrypt is a general purpose crypto library based on the code used
in GNU Privacy Guard. This package contains files needed to develop
applications using libgcrypt.

%prep
%setup -q
%patch2 -p1 -b .use-fipscheck
%patch5 -p1 -b .tests
%patch6 -p1 -b .cfgrandom
%patch7 -p1 -b .cavs
%patch11 -p1 -b .use-poll
%patch13 -p1 -b .gccopt
%patch18 -p1 -b .fips-ctor
%patch22 -p1 -b .fips-reqs
%patch23 -p1 -b .aliasing
%patch24 -p1 -b .urandom-only

cp -p %{SOURCE6} tests/

%build
%configure \
		--enable-noexecstack \
		--enable-hmac-binary-check \
		--disable-static \
%ifarch sparc64
		--disable-asm \
%endif
		--disable-O-flag-munging

# Kill bogus RPATHs
sed -i 's|^sys_lib_dlsearch_path_spec="/lib /usr/lib|sys_lib_dlsearch_path_spec="/%{_lib} %{_libdir}|' libtool

make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} INSTALL="install -p" install

# Change /usr/lib64 back to /usr/lib.  This saves us from having to patch the
# script to "know" that -L/usr/lib64 should be suppressed, and also removes
# a file conflict between 32- and 64-bit versions of this package.
# Also replace my_host with none.
sed -i -e 's,^libdir="/usr/lib.*"$,libdir="/usr/lib",g' %{buildroot}%{_bindir}/libgcrypt-config
sed -i -e 's,^my_host=".*"$,my_host="none",g' %{buildroot}%{_bindir}/libgcrypt-config

# Remove files we don't want packaged
rm %{buildroot}%{_infodir}/dir
rm %{buildroot}%{_libdir}/*.la

# Relocate the shared libraries to /%%{_lib}
%if ! %{UsrMove}
mkdir -p %{buildroot}/%{_lib}
for shlib in %{buildroot}%{_libdir}/*.so*; do
	if [ -L ${shlib} ]; then
		shlib_target=$(basename $(readlink ${shlib}))
		rm ${shlib}
		[ $(basename ${shlib}) = libgcrypt.so ] && ln -s %{buildroot}/%{_lib}/${shlib_target} ${shlib}
	else
		mv ${shlib} %{buildroot}/%{_lib}/
	fi
done
symlinks -cs %{buildroot}%{_libdir}

# Add the soname symlink back in
/sbin/ldconfig -n %{buildroot}/%{_lib}/
%endif

# Create /etc/gcrypt (hardwired, not dependent on the configure invocation) so
# that _someone_ owns it.
mkdir -p -m 755 %{buildroot}/etc/gcrypt

%check
%{__fipshmac} src/.libs/libgcrypt.so.??
make check

# Add generation of HMAC checksums of the final stripped binaries
%global __spec_install_post \
	%{?__debug_package:%{__debug_install_post}} \
	%{__arch_install_post} \
	%{__os_install_post} \
	%{__fipshmac} %{buildroot}%{library_dir}/*.so.?? \
%{nil}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post devel
/sbin/install-info %{_infodir}/gcrypt.info.gz %{_infodir}/dir || :

%preun devel
if [ $1 = 0 ]; then
	/sbin/install-info --delete %{_infodir}/gcrypt.info.gz %{_infodir}/dir || :
fi

%files
%if 0%{?_licensedir:1}
%license COPYING.LIB
%else
%doc COPYING.LIB
%endif
%doc AUTHORS NEWS THANKS
%dir /etc/gcrypt
%{library_dir}/libgcrypt.so.20
%{library_dir}/libgcrypt.so.20.*
%{library_dir}/.libgcrypt.so.20.hmac

%files devel
%if 0%{?_licensedir:1}
%license COPYING
%else
%doc COPYING
%endif
%{_bindir}/dumpsexp
%{_bindir}/hmac256
%{_bindir}/libgcrypt-config
%{_bindir}/mpicalc
%{_includedir}/gcrypt.h
%{_libdir}/libgcrypt.so
%{_datadir}/aclocal/libgcrypt.m4
%{_infodir}/gcrypt.info*
%{_mandir}/man1/hmac256.1*

%changelog
* Wed Nov 15 2017 Paul Howarth <paul@city-fan.org> - 1.7.9-1.0.cf
- Update to 1.7.9
  - Mitigate a local side-channel attack on Curve25519 dubbed "May the Fourth
    be With You" (CVE-2017-0379)

* Fri Aug  4 2017 Paul Howarth <paul@city-fan.org> - 1.7.8-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Fri Jul 28 2017 Paul Howarth <paul@city-fan.org> - 1.7.8-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Tue Jul  4 2017 Paul Howarth <paul@city-fan.org> - 1.7.8-1.0.cf
- Update to 1.7.8
  - Mitigate a flush+reload side-channel attack on RSA secret keys dubbed
    "Sliding right into disaster"; for details see
    https://eprint.iacr.org/2017/627 (CVE-2017-7526)
  - See NEWS for further details

* Sun Aug 21 2016 Paul Howarth <paul@city-fan.org> - 1.6.6-1.0.cf
- Update to 1.6.6
  - Fix critical security bug in the RNG (CVE-2016-6313); an attacker who
    obtains 580 bytes from the standard RNG can trivially predict the next 20
    bytes of output

* Thu Jul 21 2016 Paul Howarth <paul@city-fan.org> - 1.6.5-1.0.cf
- Update to 1.6.5
  - Mitigate side-channel attack on ECDH with Weierstrass curves
    (CVE-2015-7511); see http://www.cs.tau.ac.il/~tromer/ecdh/ for details
  - Fix build problem on Solaris

* Thu Feb  4 2016 Paul Howarth <paul@city-fan.org> - 1.6.4-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Feb  1 2016 Paul Howarth <paul@city-fan.org> - 1.6.4-1.1.cf
- Prefer %%global over %%define

* Mon Sep 14 2015 Paul Howarth <paul@city-fan.org> - 1.6.4-1.0.cf
- Update to 1.6.4
  - Speed up the random number generator by requiring less extra seeding
  - New flag "no-keytest" for ECC key generation; due to a bug in the parser
    that flag will also be accepted but ignored by older version of Libgcrypt
  - Always verify a created RSA signature to avoid private key leaks due to
    hardware failures
  - Fix alignment bug in the AESNI code on Windows > 7
  - Support FreeBSD 10 and later
  - Other minor bug fixes

* Sat Jun 20 2015 Paul Howarth <paul@city-fan.org> - 1.6.3-5.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun Apr  5 2015 Paul Howarth <paul@city-fan.org> - 1.6.3-4.0.cf
- De-initialize the RNG after the selftest is run

* Tue Mar 24 2015 Paul Howarth <paul@city-fan.org> - 1.6.3-3.0.cf
- Touch only urandom in the selftest and when /dev/random is unavailable, for
  example by SELinux confinement
- Fix the RSA selftest key (p q swap) (#1204517)

* Sun Mar 15 2015 Paul Howarth <paul@city-fan.org> - 1.6.3-2.0.cf
- Do not use strict aliasing for bufhelp functions (#1201219)

* Mon Mar  9 2015 Paul Howarth <paul@city-fan.org> - 1.6.3-1.0.cf
- Update to 1.6.3:
  - Use ciphertext blinding for Elgamal decryption (CVE-2014-3591)
    See http://www.cs.tau.ac.il/~tromer/radioexp/ for details
  - Fixed data-dependent timing variations in modular exponentiation (related
    to CVE-2015-0837, Last-Level Cache Side-Channel Attacks are Practical)
  - Improved asm support for older toolchains

* Wed Feb 25 2015 Paul Howarth <paul@city-fan.org> - 1.6.2-4.0.cf
- Do not initialize secure memory during the selftest (#1195850)

* Sun Feb 22 2015 Paul Howarth <paul@city-fan.org> - 1.6.2-3.0.cf
- Rebuilt for Fedora 23 Change
  https://fedoraproject.org/wiki/Changes/Harden_all_packages_with_position-independent_code

* Fri Jan 16 2015 Paul Howarth <paul@city-fan.org> - 1.6.2-2.0.cf
- Fix buildability of programs using gcrypt.h with -ansi (#1182200)

* Wed Dec 10 2014 Paul Howarth <paul@city-fan.org> - 1.6.2-1.0.cf
- Update to 1.6.2:
  - Map deprecated RSA algo number to the RSA algo number for better backward
    compatibility
  - Support a 0x40 compression prefix for EdDSA
  - Improve ARM hardware feature detection and building
  - Fix powerpc-apple-darwin detection
  - Fix building for the x32 ABI platform
  - Support building using the latest mingw-w64 toolchain
  - Fix some possible NULL deref bugs

* Tue Aug 19 2014 Paul Howarth <paul@city-fan.org> - 1.6.1-7.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Fri Jul 18 2014 Paul Howarth <paul@city-fan.org> - 1.6.1-6.0.cf
- Use %%license where possible

* Mon Jun  9 2014 Paul Howarth <paul@city-fan.org> - 1.6.1-5.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun May 25 2014 Paul Howarth <paul@city-fan.org> - 1.6.1-4.0.cf
- Re-enable below algos: apply patch from upstream list to make that code
  -fPIC friendly (#1069792)

* Tue May 20 2014 Paul Howarth <paul@city-fan.org> - 1.6.1-3.0.cf
- Disable rijndael, cast5, camellia ARM assembly, as it's non-PIC as
  presently written, which results in .text relocations in the shared
  library (#1069792)

* Sat Apr 26 2014 Paul Howarth <paul@city-fan.org> - 1.6.1-2.0.cf
- Drop the temporary compat shared library version
- Fix the soname version in -use-fipscheck.patch

* Sat Mar  1 2014 Paul Howarth <paul@city-fan.org> - 1.6.1-1.0.cf
- Update to 1.6.1:
  Changes in 1.6.0:
  - Removed the long-deprecated gcry_ac interface, thus Libgcrypt is no
    longer ABI-compatible with previous versions
  - Removed the module register subsystem
  - The deprecated message digest debug macros have been removed; use
    gcry_md_debug instead
  - Removed deprecated control codes
  - Improved performance of most cipher algorithms as well as for the SHA
    family of hash functions
  - Added support for the IDEA cipher algorithm
  - Added support for the Salsa20 and reduced Salsa20/12 stream ciphers
  - Added limited support for the GOST 28147-89 cipher algorithm
  - Added support for the GOST R 34.11-94 and R 34.11-2012 (Stribog) hash
    algorithms
  - Added a random number generator to directly use the system's RNG; also
    added an interface to prefer the use of a specified RNG
  - Added support for the SCRYPT algorithm
  - Mitigated the Yarom/Falkner flush+reload side-channel attack on RSA secret
    keys; see http://eprint.iacr.org/2013/448 (CVE-2013-4242)
  - Added support for Deterministic DSA as per RFC-6969
  - Added support for curve Ed25519
  - Added a scatter gather hash convenience function
  - Added several MPI amd SEXP helper functions
  - Added support for negative numbers to gcry_mpi_print, gcry_mpi_aprint and
    gcry_mpi_scan
  - The algorithm ids GCRY_PK_ECDSA and GCRY_PK_ECDH are now deprecated; use
    GCRY_PK_ECC if you need an algorithm id
  - Changed gcry_pk_genkey for "ecc" to only include the curve name and not the
    parameters; the flag "param" may be used to revert this
  - Added a feature to globally disable selected hardware features
  - Added debug helper functions
  - See NEWS for a full list of interface changes relative to the 1.5.0 release
  Changes in 1.6.1:
  - Added emulation for broken Whirlpool code prior to 1.6.0
  - Improved performance of KDF functions
  - Improved ECDSA compliance
  - Fixed locking for Windows and non-ELF Pthread systems (regression in 1.6.0)
  - Fixed message digest lookup by OID (regression in 1.6.0)
  - Fixed a build problem on NetBSD
  - Fixed memory leaks in ECC code
  - Fixed some asm build problems and feature detection bugs
  - New symbol GCRY_MD_FLAG_BUGEMU1
- Temporarily include old version of library to avoid buildroot breakage

* Wed Jan 22 2014 Paul Howarth <paul@city-fan.org> - 1.5.3-3.0.cf
- Fix a bug in the Whirlpool hash implementation
- Speed up the PBKDF2 computation

* Tue Oct 22 2013 Paul Howarth <paul@city-fan.org> - 1.5.3-2.0.cf
- Un-hobble - use upstream's ecc support

* Sat Jul 27 2013 Paul Howarth <paul@city-fan.org> - 1.5.3-1.0.cf
- Update to 1.5.3:
  - Mitigate the Yarom/Falkner flush+reload side-channel attack on RSA secret
    keys (see http://eprint.iacr.org/2013/448)

* Thu Jun 20 2013 Paul Howarth <paul@city-fan.org> - 1.5.2-3.0.cf
- Silence false error detected by valgrind (#968288)

* Thu Apr 25 2013 Paul Howarth <paul@city-fan.org> - 1.5.2-2.0.cf
- Silence strict aliasing warning in Rijndael

* Fri Apr 19 2013 Paul Howarth <paul@city-fan.org> - 1.5.2-1.0.cf
- Update to 1.5.2:
  - Added support for IDEA
  - Made the Padlock code work again (regression since 1.5.0)
  - Fixed alignment problems for Serpent
  - Fixed two bugs in ECC computations

* Wed Mar 20 2013 Paul Howarth <paul@city-fan.org> - 1.5.1-1.0.cf
- Update to 1.5.1:
  - Allow empty passphrase with PBKDF2
  - Do not abort on an invalid algorithm number in gcry_cipher_get_algo_keylen
    and gcry_cipher_get_algo_blklen
  - Fixed some Valgrind warnings
  - Fixed a problem with select and high fd numbers
  - Improved the build system
  - Various minor bug fixes
  - New symbols GCRYCTL_SET_ENFORCED_FIPS_FLAG and GCRYPT_VERSION_NUMBER
- Drop upstreamed patches, update poll patch

* Thu Mar  7 2013 Paul Howarth <paul@city-fan.org> - 1.5.0-11.0.cf
- Use poll() instead of select() when gathering randomness (#913773)

* Sat Feb 23 2013 Paul Howarth <paul@city-fan.org> - 1.5.0-10.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jan  3 2013 Paul Howarth <paul@city-fan.org> - 1.5.0-9.0.cf
- Allow empty passphrase in PBKDF2 needed for cryptsetup (#891266)

* Mon Dec  3 2012 Paul Howarth <paul@city-fan.org> - 1.5.0-8.0.cf
- Fix multilib conflict in libgcrypt-config
- Fix minor memory leaks and other bugs found by Coverity scan

* Tue Jul 24 2012 Paul Howarth <paul@city-fan.org> - 1.5.0-6.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Apr  6 2012 Paul Howarth <paul@city-fan.org> - 1.5.0-5.0.cf
- Add GCRYCTL_SET_ENFORCED_FIPS_FLAG command
- BR: texinfo since we're patching the .texi doc

* Mon Apr  2 2012 Paul Howarth <paul@city-fan.org> - 1.5.0-4.0.cf
- From F-17/RHEL-7 onwards, install to %%{_libdir} rather than /%%{_lib}
  (https://fedoraproject.org/wiki/Features/UsrMove)
- Retain upstream timestamps where possible
- Drop support for distributions prior to F-16:
  - Enable fipscheck unconditionally
  - Drop %%defattr, redundant since rpm 4.4
  - Drop buildroot definition and cleaning
  - devel sub-package never needs to require automake
  - Never need --disable-aesni-support

* Wed Jan 18 2012 Paul Howarth <paul@city-fan.org> - 1.5.0-3.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Aug 15 2011 Paul Howarth <paul@city-fan.org> - 1.5.0-2.0.cf
- Rebuild for rpm bug #728707

* Thu Jul 21 2011 Paul Howarth <paul@city-fan.org> - 1.5.0-1.0.cf
- Update to 1.5.0
  - New function gcry_kdf_derive implementing OpenPGP S2K algorithms and PBKDF2
  - Support for WindowsCE
  - Support for ECDH
  - Support for OAEP and PSS methods as described by RFC-3447
  - Fixed PKCS v1.5 code to always return the leading zero
  - New format specifiers "%%M" and "%%u" for gcry_sexp_build
  - Support opaque MPIs with "%%m" and "%%M" in gcry_sexp_build
  - New functions gcry_pk_get_curve and gcry_pk_get_param to map ECC
    parameters to a curve name and to retrieve parameter values
  - gcry_mpi_cmp applied to opaque values has a defined semantic now
  - Uses the Intel AES-NI instructions if available
  - The use of the deprecated Alternative Public Key Interface (gcry_ac_*)
    will now print compile time warnings
  - The module register subsystem has been deprecated
  - CTR mode may now be used with data chunks of arbitrary length
- Disable AES-NI use for Fedora 4 i386 build, where it doesn't work
  (http://mail-index.netbsd.org/pkgsrc-users/2011/07/15/msg014687.html)
- Use a patch rather than scripted iconv to fix character encoding
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue Jun 21 2011 Paul Howarth <paul@city-fan.org> - 1.4.6-4.0.cf
- Always xor seed from /dev/urandom over /etc/gcrypt/rngseed

* Tue May 31 2011 Paul Howarth <paul@city-fan.org> - 1.4.6-3.0.cf
- Make the FIPS-186-3 DSA implementation CAVS testable
- Add configurable source of RNG seed /etc/gcrypt/rngseed
  in the FIPS mode (#700388)

* Tue May 31 2011 Paul Howarth <paul@city-fan.org> - 1.4.6-2.0.cf
- Nobody else likes macros for commands

* Fri Feb 11 2011 Paul Howarth <paul@city-fan.org> - 1.4.6-1.0.cf
- Update to 1.4.6
  - New variants of the TIGER algorithm
  - New cipher algorithm mode for AES-WRAP

* Mon Feb  7 2011 Paul Howarth <paul@city-fan.org> - 1.4.5-6.0.cf
- Fix a bug in the FIPs-186-3 dsa parameter generation code
- Use /dev/urandom for seeding in the FIPS mode
- Make the tests pass in the FIPS mode

* Fri May 14 2010 Paul Howarth <paul@city-fan.org> - 1.4.5-5.0.cf
- Fix dist tag for RHEL-4
- Don't need automake dependency in devel package from F-14

* Tue Feb 23 2010 Paul Howarth <paul@city-fan.org> - 1.4.5-4.0.cf
- Update to 1.4.5
  - Fixed minor memory leak in DSA key generation
  - No more switching to FIPS mode if /proc/version is not readable
  - Fixed a sigill during Padlock detection on old CPUs
  - Fixed a hang on some W2000 machines
  - Boosted SHA-256/512 performance on ia32 boxes with gcc 4.3
- Fix FTBFS: ImplicitDSOLinking (#564973)
- Disable upstream's fiddling with compiler optimization flags
- Clarify license - some parts of devel package are GPLV2+
- Include credits, license text and NEWS as %%doc
- Change URL from directory.fsf.org to www.gnupg.org
- Tighten devel package's dependency on main package
- Dist tag for Rawhide no longer needs special-casing

* Thu Jun 18 2009 Paul Howarth <paul@city-fan.org> - 1.4.4-6.0.cf
- Fix VIA padlock RNG inline assembly call (#505724)
- fipshmac moved from /bin to /usr/bin, except on EL-5, so cater for both

* Fri Mar  6 2009 Paul Howarth <paul@city-fan.org> - 1.4.4-4.0.cf
- Rebuild for city-fan.org repo

* Thu Mar  5 2009 Tomas Mraz <tmraz@redhat.com> - 1.4.4-4
- With the integrity verification check the library needs to link to libdl
  (#488702)

* Wed Mar  4 2009 Paul Howarth <paul@city-fan.org> - 1.4.4-3.0.cf
- Add hmac FIPS integrity verification check where openssl supports it

* Tue Mar  3 2009 Paul Howarth <paul@city-fan.org> - 1.4.4-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Mar  3 2009 Paul Howarth <paul@city-fan.org> - 1.4.4-1.0.cf
- Import from Fedora
- Simplify library relocation to /%%{_lib} by using the symlinks program
- Kill rpaths to /usr/lib64
- Fix scriptlet dependencies
- Add URL tag
- This is a stable version, so remove bit about it being a development version
  from the package description

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.4.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Jan 30 2009 Tomas Mraz <tmraz@redhat.com> - 1.4.4-1
- Update to 1.4.4
- Do not abort when the fips mode kernel flag is inaccessible
  due to permissions (#470219)
- Hobble the library to drop the ECC support

* Mon Oct 20 2008 Dennis Gilmore <dennis@ausil.us> - 1.4.3-2
- Disable asm on sparc64

* Thu Sep 18 2008 Nalin Dahyabhai <nalin@redhat.com> - 1.4.3-1
- Update to 1.4.3
- Own /etc/gcrypt

* Mon Sep 15 2008 Nalin Dahyabhai <nalin@redhat.com>
- Invoke make with %%{?_smp_mflags} to build faster on multi-processor
  systems (Steve Grubb)

* Mon Sep  8 2008 Nalin Dahyabhai <nalin@redhat.com> - 1.4.2-1
- Update to 1.4.2

* Tue Apr 29 2008 Nalin Dahyabhai <nalin@redhat.com> - 1.4.1-1
- Update to 1.4.1
- Bump libgpgerror-devel requirement to 1.4, matching the requirement enforced
  by the configure script

* Thu Apr  3 2008 Joe Orton <jorton@redhat.com> - 1.4.0-3
- Add patch from upstream to fix severe performance regression
  in entropy gathering

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.4.0-2
- Autorebuild for GCC 4.3

* Mon Dec 10 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.4.0-1
- Update to 1.4.0

* Tue Oct 16 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.2.4-6
- Use ldconfig to build the soname symlink for packaging along with the
  shared library (#334731)

* Wed Aug 22 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.2.4-5
- Add missing gawk buildrequirement
- Switch from explicitly specifying the /dev/random RNG to just verifying
  that the non-LGPL ones were disabled by the configure script

* Thu Aug 16 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.2.4-4
- Clarify license
- Force use of the linux /dev/random RNG, to avoid accidentally falling back
  to others, which would affect the license of the resulting library

* Mon Jul 30 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.2.4-3
- Disable static libraries (part of #249815)

* Fri Jul 27 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.2.4-2
- Move libgcrypt shared library to /%%{_lib} (#249815)

* Tue Feb  6 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.2.4-1
- Update to 1.2.4

* Mon Jan 22 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.2.3-2
- Make use of install-info more failsafe (Ville Skyttä, #223705)

* Fri Sep  1 2006 Nalin Dahyabhai <nalin@redhat.com> - 1.2.3-1
- Update to 1.2.3

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 1.2.2-3.1
- Rebuild

* Mon Jun 05 2006 Jesse Keating <jkeating@redhat.com> - 1.2.2-3
- Added missing buildreq pkgconfig

* Tue May 16 2006 Nalin Dahyabhai <nalin@redhat.com> - 1.2.2-2
- Remove file conflicts in libgcrypt-config by making the 64-bit version
  think the libraries are in /usr/lib (which is wrong, but which it also
  prunes from the suggest --libs output, so no harm done, hopefully)

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 1.2.2-1.2.1
- Bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 1.2.2-1.2
- Rebuilt for new gcc4.1 snapshot and glibc changes

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- Rebuilt

* Wed Oct  5 2005 Nalin Dahyabhai <nalin@redhat.com> - 1.2.2-1
- Update to 1.2.2

* Wed Mar 16 2005 Nalin Dahyabhai <nalin@redhat.com> - 1.2.1-1
- Update to 1.2.1

* Fri Jul 30 2004 Florian La Roche <Florian.LaRoche@redhat.de>
- Another try to package the symlink

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- Rebuilt

* Sun May  2 2004 Bill Nottingham <notting@redhat.com> - 1.2.0-1
- Update to official 1.2.0

* Fri Apr 16 2004 Bill Nottingham <notting@redhat.com> - 1.1.94-1
- Update to 1.1.94

* Tue Mar 02 2004 Elliot Lee <sopwith@redhat.com>
- Rebuilt

* Sat Feb 21 2004 Florian La Roche <Florian.LaRoche@redhat.de>
- Add symlinks to shared libs at compile time

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- Rebuilt

* Wed Jun 04 2003 Elliot Lee <sopwith@redhat.com>
- Rebuilt

* Thu Mar 20 2003 Jeff Johnson <jbj@redhat.com> - 1.1.12-1
- Upgrade to 1.1.12 (beta)

* Fri Jun 21 2002 Tim Powers <timp@redhat.com>
- Automated rebuild

* Sun May 26 2002 Tim Powers <timp@redhat.com>
- Automated rebuild

* Tue May 21 2002 Jeff Johnson <jbj@redhat.com>
- Update to 1.1.7
- Change license to LGPL
- Include splint annotations patch
- Install info pages

* Tue Apr  2 2002 Nalin Dahyabhai <nalin@redhat.com> - 1.1.6-1
- Update to 1.1.6

* Thu Jan 10 2002 Nalin Dahyabhai <nalin@redhat.com> - 1.1.5-1
- Fix the Source tag so that it's a real URL

* Thu Dec 20 2001 Nalin Dahyabhai <nalin@redhat.com>
- Initial package
